/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.bean;


/**
 * トピック定数クラス<BR>
 * 
 *  リポジトリ情報の更新の際にエージェントとクライアントに
 *  その情報を通知します。通知には、JMS(TOPIC)を用いて
 *  そのトピックの名称を指定します。
 *
 * @version 2.0.0
 * @since 2.0.0
 */
public class TopicConstant {
    /** リポジトリ更新用トピック */
    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrolRepositoryUpdate";
}
